==> zzyj-outputvalcount-api-3.0.0-20230308.074201-154-sources.jar: com/ejianc/business/outputvalcount/vo/ProjectDetailDTO.java <==
package com.ejianc.business.outputvalcount.vo;

import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;


/**
 * 项目明细
 * 
 * @author generator
 * 
 */
public class ProjectDetailDTO {
    private static final long serialVersionUID = 1L;

    private Long id; // id
    private Long projectId; // 工程id
    private String projectName; // 工程名称
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date statDate; // 最新上报日期日期
    private BigDecimal kgwccz; // 累计完成产值
    private BigDecimal taxMny; //累计产值报量
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date productionDate; // 最新报量时间
    private String dataState;


    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public Date getStatDate() {
        return statDate;
    }

    public void setStatDate(Date statDate) {
        this.statDate = statDate;
    }

    public BigDecimal getKgwccz() {
        return kgwccz;
    }

    public void setKgwccz(BigDecimal kgwccz) {
        this.kgwccz = kgwccz;
    }

    public BigDecimal getTaxMny() {
        return taxMny;
    }

    public void setTaxMny(BigDecimal taxMny) {
        this.taxMny = taxMny;
    }

    public Date getProductionDate() {
        return productionDate;
    }

    public void setProductionDate(Date productionDate) {
        this.productionDate = productionDate;
    }
    
    public String getDataState() {
        return dataState;
    }

    public void setDataState(String dataState) {
        this.dataState = dataState;
    }
    
}

==> zzyj-outputvalcount-api-3.0.0-20230525.061906-170-sources.jar: com/ejianc/business/outputvalcount/vo/ProjectDetailDTO.java <==
package com.ejianc.business.outputvalcount.vo;

import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;


/**
 * 项目明细
 * 
 * @author generator
 * 
 */
public class ProjectDetailDTO {
    private static final long serialVersionUID = 1L;

    private Long id; // id
    private Long projectId; // 工程id
    private String projectName; // 工程名称
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date statDate; // 最新上报日期日期
    private BigDecimal kgwccz; // 累计完成产值
    private BigDecimal taxMny; //累计产值报量
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date productionDate; // 最新报量时间
    private String dataState;
    private BigDecimal jjf; //间接费
    private BigDecimal sj; //税金
    private BigDecimal zje; //立项金额

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public Date getStatDate() {
        return statDate;
    }

    public void setStatDate(Date statDate) {
        this.statDate = statDate;
    }

    public BigDecimal getKgwccz() {
        return kgwccz;
    }

    public void setKgwccz(BigDecimal kgwccz) {
        this.kgwccz = kgwccz;
    }

    public BigDecimal getTaxMny() {
        return taxMny;
    }

    public void setTaxMny(BigDecimal taxMny) {
        this.taxMny = taxMny;
    }

    public Date getProductionDate() {
        return productionDate;
    }

    public void setProductionDate(Date productionDate) {
        this.productionDate = productionDate;
    }
    
    public String getDataState() {
        return dataState;
    }

    public void setDataState(String dataState) {
        this.dataState = dataState;
    }

    public BigDecimal getJjf() {
        return jjf;
    }

    public void setJjf(BigDecimal jjf) {
        this.jjf = jjf;
    }

    public BigDecimal getSj() {
        return sj;
    }

    public void setSj(BigDecimal sj) {
        this.sj = sj;
    }

    public BigDecimal getZje() {
        return zje;
    }

    public void setZje(BigDecimal zje) {
        this.zje = zje;
    }
}
